---
feature_story: FS_20_88_05_60
feature_title: named args
feature_status: TODO
---
Keywords: `named_args` `keyword_args`

Named args (with positional args) are the same concept as for args to funcs in Python.

Named args are different from positional ones - they are "prefixed" with name on the command line.
TODO: The exact way this prefix will look like is still TBD (e.g. `arg_name:` or `arg_name=`).

So far, named args were not necessary feature in most of the cases because value sets themselves
can contain unique values and do not intersect.
For example, for all IP addresses, values can be prefixed with `ip.` and specifying `ip.` on the command line
will only suggest options from that specific value set (as if prefix `ip_address:` was specified).
